bayespy.utils.linalg
====================

.. automodule:: bayespy.utils.linalg

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree: generated/
   
      block_banded_solve
      chol
      chol_inv
      chol_logdet
      chol_solve
      dot
      inner
      inv
      logdet_chol
      logdet_cov
      logdet_tri
      m_dot
      mmdot
      mvdot
      outer
      solve_triangular
      tracedot
      transpose
   
   

   
   
   

   
   
   